/*
 * This application demonstrates the use of functions from gpio_lib.c
 * to let the red and yellow user LEDs blink for 10s on the TQ MBa28
 * as well as read the value of pin 1 on the gpio connector.
 * 
 * gpio pin 1	-	GPIO number 176
 * red LED	-	GPIO number 180
 * yellow LED	-	GPIO number 181
 */

#include <unistd.h> /* usleep */
#include "gpio_lib.h"

#define GPIO_PIN1	176
#define REDLED		180
#define YELLOWLED	181

int main()
{
	int iTimeout = 100;
	int iOldInput, iNewInput;

	printf("  TQ MBa28 GPIO demo  \n");

	iOldInput = GPIO_Init(GPIO_PIN1, -1);
	printf("Reading Pin1 on GPIO Connector = %d\n", iOldInput);

	GPIO_Init(REDLED, 1);
	GPIO_Init(YELLOWLED, 1);

	/* Enter loop to let LEDs blink */
	while (iTimeout--)
	{
		GPIO_Toggle(REDLED);
		if (!(iTimeout%10))
			GPIO_Toggle(YELLOWLED);

		iNewInput = GPIO_GetVal(GPIO_PIN1);
		if (iOldInput != iNewInput)
		{
			printf("Reading Pin1 on GPIO Connector = %d\n", iNewInput);
			iOldInput = iNewInput;
		}

		/* wait for 100 ms */
		usleep(100000);
	}

	GPIO_SetVal(REDLED, 0);
	GPIO_SetVal(YELLOWLED, 0);

	GPIO_Free(GPIO_PIN1);
	GPIO_Free(REDLED);
	GPIO_Free(YELLOWLED);

	printf("Finished.\n");
	return 1;
}
